"""Graphical time series visualizer and analyzer."""

__version__ = '2021.07.14'

__all__ = [
    'algorithms',
    'dialogs',
    'exporter',
    'legend',
    'mainui',
    'puplot',
    'tsplot',
    'utils',
    'types',
    'ui',
    'transformations',
]
